# react markdown editor

## Installation

```bash
npm i react-markdown-editor-cm5
or
yarn add react-markdown-editor-cm5
```

## Usage

### basic usage

```tsx
import MdEditor from 'react-markdown-editor-cm5';
import 'react-markdown-editor-cm5/lib/style.css';

function App() {
  return (
    <>
      <MdEditor initialValue=""></MdEditor>
    </>
  );
}

export default App;
```

### Config editor by codemirror

Use codemirror mode, just need import codemirror mode plugins, like:

```js
import 'codemirror/mode/gfm/gfm';
import 'codemirror/mode/javascript/javascript';
import 'codemirror/mode/htmlmixed/htmlmixed';
import 'codemirror/mode/css/css';
import 'codemirror/mode/go/go';
```

set scroll bar style

```js
import 'codemirror/addon/scroll/simplescrollbars';
import 'codemirror/addon/scroll/simplescrollbars.css';

// editor config
<MdEditor initialValue="" options={{ scrollbarStyle: 'overlay' }}></MdEditor>;
```

react-markdown-editor-cm5 preset some hint, you need import codemirror addon

```js
// hint
import 'codemirror/addon/hint/show-hint';
import 'codemirror/addon/hint/show-hint.css';
```

Search and replace, need import `searchcursor.js`

```js
import 'codemirror/addon/search/searchcursor.js';
```

Scroll bar display matching markers, need import some addon and css

```js
import 'codemirror/addon/scroll/annotatescrollbar.js';
import 'codemirror/addon/search/matchesonscrollbar.js';
import 'codemirror/addon/search/matchesonscrollbar.css';
```

Some other addons

```js
import 'codemirror/addon/edit/matchbrackets'; // match brackets
import 'codemirror/addon/edit/matchtags'; // match html tags
import 'codemirror/addon/display/placeholder'; // placeholder, if you set options.placeholder, need import this addon
import 'codemirror/addon/selection/active-line'; // line light current line
import 'codemirror/addon/search/match-highlighter';
```

Code fold, if you need fold others mode, just import their addon from `codemirror/addon/fold/...`

```js
// code fold
import 'codemirror/addon/fold/markdown-fold.js';
import 'codemirror/addon/fold/foldgutter.js';
import 'codemirror/addon/fold/foldgutter.css';
```

More usage visit [codemirror.net](https://codemirror.net/5/doc/manual.html#overview)

## API

### props

> type toolbar = 'bold' | 'checkList'| 'clear'| 'codeBlock'| 'dateTime'| 'dividing'| 'emoji'| 'fullScreen'| 'header'| | 'htmlEntities'| 'humpCase'| 'image' | 'inlineCode'| 'italic'| 'link'| 'lowerCase'| 'orderedList'| 'quote'| 'redo'| 'undo'| 'sub'| 'super'| 'table'| 'theme'| 'through'| 'toggleEditor'| 'unOrderedList'| 'upperCase'

Options interface:

```ts
interface Options extends EditorConfiguration {
  singleCursorHeightPerLine?: boolean;
  languages?: string[];
}
```

| name              | type                                                                                             | default        | description                                                           |
| :---------------- | :----------------------------------------------------------------------------------------------- | :------------- | :-------------------------------------------------------------------- |
| initialValue      | string                                                                                           |                | initial value of editor                                               |
| width             | number \| string                                                                                 | '100%'         | width of editor                                                       |
| height            | number                                                                                           | 800            | height of editor,                                                     |
| toolbars          | Array\<toolbar\>                                                                                 | all of toolbar | custom toollbar item, if it's a empty array, editor will hide toolbar |
| toolBarHeight     | number                                                                                           | 34             | height editor toolbar                                                 |
| onSave            | (mdValue?: string, htmlValue?: string): void                                                     |                | callback when editor save                                             |
| onChange          | (mdValue?: string, htmlValue?: string): void                                                     |                | callback when editor content change                                   |
| uploadImageMethod | (file: string \| Blob, insertImageCallback: (fileName: string, imageUrl: string) => void): void; |                | method of upload image                                                |
| options           | Options                                                                                          |                | codsmirror options                                                    |

### example of uploadImageMethod

No matter what your upload method is, you just need call insertImageCallback after your upload method, filename param is the title of image, the imageUrl is the image url after upload

```javascript
function App() {
  const uploadImageMethod: uploadImageMethod = (file, insertImageCallback) => {
    const uploadApi = 'http://localhost:8080/upload';
    const formData = new FormData();
    formData.append('file', file);

    fetch(uploadApi, {
      method: 'POST',
      body: formData,
    })
      .then((response) => response.json())
      .then((data) => {
        const { imgName, imageUrl } = data;
        insertImageCallback(imgName, imageUrl);
      })
      .catch((error) => {
        console.error(error);
      });
  };

  return (
    <div style={{ padding: '50px' }}>
      <MdEditor uploadImageMethod={uploadImageMethod} />
    </div>
  );
}
export default App;
```

## Features
